@@ -1162,23 +1162,23 @@ class VectorsInternalDataSpliter:
         assert len(data) == 3
         X, y, ids = data
         limite = len(X)//counter
-        print("len(X)/counter", len(X)/counter)
-        print("limite", limite)
+        #print("len(X)/counter", len(X)/counter)
+        #print("limite", limite)
         result = []
         X_result, y_result, ids_result = [],[],[]
-        print("len(X) :", len(X))
+        #print("len(X) :", len(X))
         for item in zip(X,y,ids):
             X_local, y_local, ids_local = item
             X_result.append(X_local)
             y_result.append(y_local)
             ids_result.append(ids_local)
             if len(X_result) == limite:
-                print("len(X_result) :",len(X_result))
+                #print("len(X_result) :",len(X_result))
                 result.append((X_result,y_result,ids_result))
                 X_result, y_result, ids_result = [],[],[]
 
         if len(X_result) > 0:
-            print("again len(X_result) : ", len(X_result))
+            #print("again len(X_result) : ", len(X_result))
             result.append((X_result,y_result,ids_result))
         
         return result
@@ -1187,7 +1187,7 @@ class VectorsInternalSplitedDataReader:
     def read(self, directory_path):
         X_result, y_result, ids_result = [],[],[]
         for file in os.listdir(directory_path):
-            if re.match(r'^.*_block_[0-9]+.*', file):
+            if re.match(r'block_[0-9]+.*', file):
                 print("file :", file)
                 data_vec = PickleUtilities.load_file(os.path.join(directory_path, file))
                 X,y,ids = data_vec
@@ -1245,6 +1245,9 @@ class LargeFileWriter:
         value = fileWriter.read()
         return value == self.REFERENCE_FILE_NOT_FINISHED
 
+    def has_block_file(self):
+        block_files = [f for f in os.listdir(self.directory_path) if re.match(r'block_[0-9]+.*', f)]
+        return len(block_files) > 0
 
     def write(self, data_list, ext):
         threadlist = []
